# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.deployment import deployment_service_pb2 as qwak_dot_deployment_dot_deployment__service__pb2


class DeploymentManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeployModel = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/DeployModel',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.FromString,
                )
        self.UndeployModel = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/UndeployModel',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.FromString,
                )
        self.GetDeploymentStatus = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentStatus',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.FromString,
                )
        self.GetDeploymentDetails = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentDetails',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.FromString,
                )
        self.UpdateDeploymentRuntimeSettings = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/UpdateDeploymentRuntimeSettings',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.FromString,
                )
        self.GetDeploymentHistory = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeploymentHistory',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.FromString,
                )
        self.PushEnvironmentDeploymentState = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/PushEnvironmentDeploymentState',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.FromString,
                )
        self.ApplyModelTraffic = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/ApplyModelTraffic',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.FromString,
                )
        self.GetModelTraffic = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetModelTraffic',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.FromString,
                )
        self.IsBuildDeployed = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/IsBuildDeployed',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.FromString,
                )
        self.IsBuildInUse = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/IsBuildInUse',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.FromString,
                )
        self.GetDeployment = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/GetDeployment',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.FromString,
                )
        self.CancelDeployments = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/CancelDeployments',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.FromString,
                )
        self.ListLiveModelsDeployments = channel.unary_unary(
                '/qwak.deployment.management.DeploymentManagementService/ListLiveModelsDeployments',
                request_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.SerializeToString,
                response_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.FromString,
                )


class DeploymentManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeployModel(self, request, context):
        """Deploy specified model to one of the supported downstream tools
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployModel(self, request, context):
        """Undeploy model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentStatus(self, request, context):
        """Get the status of a deployment. Main use case is deployment status polling
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentDetails(self, request, context):
        """Get model's deployment details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeploymentRuntimeSettings(self, request, context):
        """Set the setting on runtime deployed model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeploymentHistory(self, request, context):
        """Get Deployments history for model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PushEnvironmentDeploymentState(self, request, context):
        """Push environment deployments status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyModelTraffic(self, request, context):
        """Apply Model Traffic Changes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelTraffic(self, request, context):
        """Get Model Traffic Variation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsBuildDeployed(self, request, context):
        """Checks if a build is deployed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsBuildInUse(self, request, context):
        """Checks if a build is in use
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeployment(self, request, context):
        """Get specific deployment 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelDeployments(self, request, context):
        """Cancel the deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLiveModelsDeployments(self, request, context):
        """Get Current (deployed or in progress) Deployments For Model
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeploymentManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployModel,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.SerializeToString,
            ),
            'UndeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployModel,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.SerializeToString,
            ),
            'GetDeploymentStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentStatus,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.SerializeToString,
            ),
            'GetDeploymentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentDetails,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.SerializeToString,
            ),
            'UpdateDeploymentRuntimeSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeploymentRuntimeSettings,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.SerializeToString,
            ),
            'GetDeploymentHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeploymentHistory,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.SerializeToString,
            ),
            'PushEnvironmentDeploymentState': grpc.unary_unary_rpc_method_handler(
                    servicer.PushEnvironmentDeploymentState,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.SerializeToString,
            ),
            'ApplyModelTraffic': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyModelTraffic,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.SerializeToString,
            ),
            'GetModelTraffic': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelTraffic,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.SerializeToString,
            ),
            'IsBuildDeployed': grpc.unary_unary_rpc_method_handler(
                    servicer.IsBuildDeployed,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.SerializeToString,
            ),
            'IsBuildInUse': grpc.unary_unary_rpc_method_handler(
                    servicer.IsBuildInUse,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.SerializeToString,
            ),
            'GetDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeployment,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.SerializeToString,
            ),
            'CancelDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelDeployments,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.SerializeToString,
            ),
            'ListLiveModelsDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLiveModelsDeployments,
                    request_deserializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.FromString,
                    response_serializer=qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.deployment.management.DeploymentManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeploymentManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/DeployModel',
            qwak_dot_deployment_dot_deployment__service__pb2.DeployModelRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.DeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/UndeployModel',
            qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.UndeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentStatus',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentDetails',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDeploymentRuntimeSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/UpdateDeploymentRuntimeSettings',
            qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.UpdateDeploymentRuntimeSettingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeploymentHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeploymentHistory',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PushEnvironmentDeploymentState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/PushEnvironmentDeploymentState',
            qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.PushEnvironmentDeploymentStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyModelTraffic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/ApplyModelTraffic',
            qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.ApplyModelTrafficResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelTraffic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetModelTraffic',
            qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetModelTrafficResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsBuildDeployed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/IsBuildDeployed',
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildDeployedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsBuildInUse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/IsBuildInUse',
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.IsBuildInUseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/GetDeployment',
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.GetDeploymentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/CancelDeployments',
            qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.CancelDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLiveModelsDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.deployment.management.DeploymentManagementService/ListLiveModelsDeployments',
            qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsRequest.SerializeToString,
            qwak_dot_deployment_dot_deployment__service__pb2.ListLiveModelsDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
