"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OpenAIIntegration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_SYSTEM_SECRET_DESCRIPTOR_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_system_secret_descriptor(self) -> global___OpenAIApiKeySystemSecretDescriptor:
        """OpenAI system secret descriptor"""
    def __init__(
        self,
        *,
        openai_api_key_system_secret_descriptor: global___OpenAIApiKeySystemSecretDescriptor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_system_secret_descriptor", b"openai_api_key_system_secret_descriptor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_system_secret_descriptor", b"openai_api_key_system_secret_descriptor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_system_secret_descriptor"] | None: ...

global___OpenAIIntegration = OpenAIIntegration

class OpenAIIntegrationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_auth_config(self) -> global___OpenAIApiKeyAuthConfig: ...
    def __init__(
        self,
        *,
        openai_api_key_auth_config: global___OpenAIApiKeyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_auth_config"] | None: ...

global___OpenAIIntegrationSpec = OpenAIIntegrationSpec

class OpenAIApiKeyAuthConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    def __init__(
        self,
        *,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key"]) -> None: ...

global___OpenAIApiKeyAuthConfig = OpenAIApiKeyAuthConfig

class OpenAIApiKeySystemSecretDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    API_KEY_SECRET_KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    """OpenAI system secret name"""
    api_key_secret_key: builtins.str
    """OpenAI system secret api_key secret key"""
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        api_key_secret_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key_secret_key", b"api_key_secret_key", "secret_name", b"secret_name"]) -> None: ...

global___OpenAIApiKeySystemSecretDescriptor = OpenAIApiKeySystemSecretDescriptor

class OpenAIValidationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPENAI_API_KEY_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def openai_api_key_auth_config(self) -> global___OpenAIApiKeyAuthConfig: ...
    def __init__(
        self,
        *,
        openai_api_key_auth_config: global___OpenAIApiKeyAuthConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "openai_api_key_auth_config", b"openai_api_key_auth_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth", b"auth"]) -> typing_extensions.Literal["openai_api_key_auth_config"] | None: ...

global___OpenAIValidationSpec = OpenAIValidationSpec

class OpenAIIntegrationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OpenAIIntegrationOptions = OpenAIIntegrationOptions
