# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/offline/serving/v1/offline_serving_async_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.offline.serving.v1 import population_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_population__pb2
from _qwak_proto.qwak.offline.serving.v1 import feature_values_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_feature__values__pb2
from _qwak_proto.qwak.offline.serving.v1 import options_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;qwak/offline/serving/v1/offline_serving_async_service.proto\x12%qwak.feature.store.offline.serving.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(qwak/offline/serving/v1/population.proto\x1a,qwak/offline/serving/v1/feature_values.proto\x1a%qwak/offline/serving/v1/options.proto\"{\n\x17GetFileUploadUrlRequest\x12X\n\npopulation\x18\x01 \x01(\x0b\x32\x42.qwak.feature.store.offline.serving.v1.PopulationFileUploadUrlTypeH\x00\x42\x06\n\x04type\"3\n\x18GetFileUploadUrlResponse\x12\x17\n\x0f\x66ile_upload_url\x18\x01 \x01(\t\"\xd5\x02\n\x17GetFeatureValuesRequest\x12K\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\x39.qwak.feature.store.offline.serving.v1.FeaturesetFeatures\x12J\n\npopulation\x18\x02 \x01(\x0b\x32\x36.qwak.feature.store.offline.serving.v1.TimedPopulation\x12M\n\x12result_file_format\x18\x03 \x01(\x0e\x32\x31.qwak.feature.store.offline.serving.v1.FileFormat\x12R\n\x07options\x18\x04 \x01(\x0b\x32\x41.qwak.feature.store.offline.serving.v1.OfflineServingQueryOptions\".\n\x18GetFeatureValuesResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\xdc\x03\n\x1eGetFeatureValuesInRangeRequest\x12K\n\x08\x66\x65\x61tures\x18\x01 \x01(\x0b\x32\x39.qwak.feature.store.offline.serving.v1.FeaturesetFeatures\x12\x34\n\x10lower_time_bound\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10upper_time_bound\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\npopulation\x18\x04 \x01(\x0b\x32\x31.qwak.feature.store.offline.serving.v1.PopulationH\x00\x12M\n\x12result_file_format\x18\x05 \x01(\x0e\x32\x31.qwak.feature.store.offline.serving.v1.FileFormat\x12R\n\x07options\x18\x06 \x01(\x0b\x32\x41.qwak.feature.store.offline.serving.v1.OfflineServingQueryOptionsB\x15\n\x13optional_population\"5\n\x1fGetFeatureValuesInRangeResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"3\n\x1dGetFeatureValuesResultRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x9b\x02\n\x1eGetFeatureValuesResultResponse\x12Q\n\x06status\x18\x01 \x01(\x0e\x32\x41.qwak.feature.store.offline.serving.v1.FeatureValuesRequestStatus\x12K\n\rlink_to_files\x18\x02 \x01(\x0b\x32\x32.qwak.feature.store.offline.serving.v1.LinkToFilesH\x00\x12N\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\x0b\x32\x34.qwak.feature.store.offline.serving.v1.FailureReasonH\x00\x42\t\n\x07payload\" \n\rFailureReason\x12\x0f\n\x07message\x18\x01 \x01(\t\"$\n\x0bLinkToFiles\x12\x15\n\rlink_to_files\x18\x01 \x03(\t*\xf6\x01\n\x1a\x46\x65\x61tureValuesRequestStatus\x12)\n%FEATURE_VALUES_REQUEST_STATUS_INVALID\x10\x00\x12+\n\'FEATURE_VALUES_REQUEST_STATUS_SUCCEEDED\x10\x01\x12)\n%FEATURE_VALUES_REQUEST_STATUS_PENDING\x10\x02\x12+\n\'FEATURE_VALUES_REQUEST_STATUS_CANCELLED\x10\x03\x12(\n$FEATURE_VALUES_REQUEST_STATUS_FAILED\x10\x04*:\n\nFileFormat\x12\x17\n\x13\x46ILE_FORMAT_INVALID\x10\x00\x12\x13\n\x0f\x46ILE_FORMAT_CSV\x10\x01\x32\xa7\x05\n&FeatureStoreOfflineServingAsyncService\x12\x93\x01\n\x10GetFileUploadUrl\x12>.qwak.feature.store.offline.serving.v1.GetFileUploadUrlRequest\x1a?.qwak.feature.store.offline.serving.v1.GetFileUploadUrlResponse\x12\x93\x01\n\x10GetFeatureValues\x12>.qwak.feature.store.offline.serving.v1.GetFeatureValuesRequest\x1a?.qwak.feature.store.offline.serving.v1.GetFeatureValuesResponse\x12\xa8\x01\n\x17GetFeatureValuesInRange\x12\x45.qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeRequest\x1a\x46.qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeResponse\x12\xa5\x01\n\x16GetFeatureValuesResult\x12\x44.qwak.feature.store.offline.serving.v1.GetFeatureValuesResultRequest\x1a\x45.qwak.feature.store.offline.serving.v1.GetFeatureValuesResultResponseB&\n\"com.qwak.ai.offline.serving.api.v1P\x01\x62\x06proto3')

_FEATUREVALUESREQUESTSTATUS = DESCRIPTOR.enum_types_by_name['FeatureValuesRequestStatus']
FeatureValuesRequestStatus = enum_type_wrapper.EnumTypeWrapper(_FEATUREVALUESREQUESTSTATUS)
_FILEFORMAT = DESCRIPTOR.enum_types_by_name['FileFormat']
FileFormat = enum_type_wrapper.EnumTypeWrapper(_FILEFORMAT)
FEATURE_VALUES_REQUEST_STATUS_INVALID = 0
FEATURE_VALUES_REQUEST_STATUS_SUCCEEDED = 1
FEATURE_VALUES_REQUEST_STATUS_PENDING = 2
FEATURE_VALUES_REQUEST_STATUS_CANCELLED = 3
FEATURE_VALUES_REQUEST_STATUS_FAILED = 4
FILE_FORMAT_INVALID = 0
FILE_FORMAT_CSV = 1


_GETFILEUPLOADURLREQUEST = DESCRIPTOR.message_types_by_name['GetFileUploadUrlRequest']
_GETFILEUPLOADURLRESPONSE = DESCRIPTOR.message_types_by_name['GetFileUploadUrlResponse']
_GETFEATUREVALUESREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesRequest']
_GETFEATUREVALUESRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesResponse']
_GETFEATUREVALUESINRANGEREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesInRangeRequest']
_GETFEATUREVALUESINRANGERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesInRangeResponse']
_GETFEATUREVALUESRESULTREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureValuesResultRequest']
_GETFEATUREVALUESRESULTRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureValuesResultResponse']
_FAILUREREASON = DESCRIPTOR.message_types_by_name['FailureReason']
_LINKTOFILES = DESCRIPTOR.message_types_by_name['LinkToFiles']
GetFileUploadUrlRequest = _reflection.GeneratedProtocolMessageType('GetFileUploadUrlRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEUPLOADURLREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFileUploadUrlRequest)
  })
_sym_db.RegisterMessage(GetFileUploadUrlRequest)

GetFileUploadUrlResponse = _reflection.GeneratedProtocolMessageType('GetFileUploadUrlResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEUPLOADURLRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFileUploadUrlResponse)
  })
_sym_db.RegisterMessage(GetFileUploadUrlResponse)

GetFeatureValuesRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesRequest)

GetFeatureValuesResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesResponse)

GetFeatureValuesInRangeRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesInRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESINRANGEREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesInRangeRequest)

GetFeatureValuesInRangeResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesInRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESINRANGERESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesInRangeResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesInRangeResponse)

GetFeatureValuesResultRequest = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESULTREQUEST,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResultRequest)
  })
_sym_db.RegisterMessage(GetFeatureValuesResultRequest)

GetFeatureValuesResultResponse = _reflection.GeneratedProtocolMessageType('GetFeatureValuesResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREVALUESRESULTRESPONSE,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.GetFeatureValuesResultResponse)
  })
_sym_db.RegisterMessage(GetFeatureValuesResultResponse)

FailureReason = _reflection.GeneratedProtocolMessageType('FailureReason', (_message.Message,), {
  'DESCRIPTOR' : _FAILUREREASON,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.FailureReason)
  })
_sym_db.RegisterMessage(FailureReason)

LinkToFiles = _reflection.GeneratedProtocolMessageType('LinkToFiles', (_message.Message,), {
  'DESCRIPTOR' : _LINKTOFILES,
  '__module__' : 'qwak.offline.serving.v1.offline_serving_async_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.offline.serving.v1.LinkToFiles)
  })
_sym_db.RegisterMessage(LinkToFiles)

_FEATURESTOREOFFLINESERVINGASYNCSERVICE = DESCRIPTOR.services_by_name['FeatureStoreOfflineServingAsyncService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.offline.serving.api.v1P\001'
  _FEATUREVALUESREQUESTSTATUS._serialized_start=1778
  _FEATUREVALUESREQUESTSTATUS._serialized_end=2024
  _FILEFORMAT._serialized_start=2026
  _FILEFORMAT._serialized_end=2084
  _GETFILEUPLOADURLREQUEST._serialized_start=262
  _GETFILEUPLOADURLREQUEST._serialized_end=385
  _GETFILEUPLOADURLRESPONSE._serialized_start=387
  _GETFILEUPLOADURLRESPONSE._serialized_end=438
  _GETFEATUREVALUESREQUEST._serialized_start=441
  _GETFEATUREVALUESREQUEST._serialized_end=782
  _GETFEATUREVALUESRESPONSE._serialized_start=784
  _GETFEATUREVALUESRESPONSE._serialized_end=830
  _GETFEATUREVALUESINRANGEREQUEST._serialized_start=833
  _GETFEATUREVALUESINRANGEREQUEST._serialized_end=1309
  _GETFEATUREVALUESINRANGERESPONSE._serialized_start=1311
  _GETFEATUREVALUESINRANGERESPONSE._serialized_end=1364
  _GETFEATUREVALUESRESULTREQUEST._serialized_start=1366
  _GETFEATUREVALUESRESULTREQUEST._serialized_end=1417
  _GETFEATUREVALUESRESULTRESPONSE._serialized_start=1420
  _GETFEATUREVALUESRESULTRESPONSE._serialized_end=1703
  _FAILUREREASON._serialized_start=1705
  _FAILUREREASON._serialized_end=1737
  _LINKTOFILES._serialized_start=1739
  _LINKTOFILES._serialized_end=1775
  _FEATURESTOREOFFLINESERVINGASYNCSERVICE._serialized_start=2087
  _FEATURESTOREOFFLINESERVINGASYNCSERVICE._serialized_end=2766
# @@protoc_insertion_point(module_scope)
