"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SqlEngineConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATHENA_SQL_ENGINE_CONFIGURATION_FIELD_NUMBER: builtins.int
    BIG_QUERY_SQL_ENGINE_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def athena_sql_engine_configuration(self) -> global___AthenaSqlEngineConfig: ...
    @property
    def big_query_sql_engine_configuration(self) -> global___BigQuerySqlEngineConfig: ...
    def __init__(
        self,
        *,
        athena_sql_engine_configuration: global___AthenaSqlEngineConfig | None = ...,
        big_query_sql_engine_configuration: global___BigQuerySqlEngineConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["athena_sql_engine_configuration", b"athena_sql_engine_configuration", "big_query_sql_engine_configuration", b"big_query_sql_engine_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["athena_sql_engine_configuration", b"athena_sql_engine_configuration", "big_query_sql_engine_configuration", b"big_query_sql_engine_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["athena_sql_engine_configuration", "big_query_sql_engine_configuration"] | None: ...

global___SqlEngineConfiguration = SqlEngineConfiguration

class AthenaSqlEngineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    WORKGROUP_FIELD_NUMBER: builtins.int
    external_id: builtins.str
    workgroup: builtins.str
    def __init__(
        self,
        *,
        external_id: builtins.str = ...,
        workgroup: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_id", b"external_id", "workgroup", b"workgroup"]) -> None: ...

global___AthenaSqlEngineConfig = AthenaSqlEngineConfig

class BigQuerySqlEngineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BigQuerySqlEngineConfig = BigQuerySqlEngineConfig
