"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.entities.entity_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_SPEC_FIELD_NUMBER: builtins.int
    @property
    def entity_spec(self) -> qwak.feature_store.entities.entity_pb2.EntitySpec:
        """Entity specifications to create"""
    def __init__(
        self,
        *,
        entity_spec: qwak.feature_store.entities.entity_pb2.EntitySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> None: ...

global___CreateEntityRequest = CreateEntityRequest

class UpdateEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    ENTITY_SPEC_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Entity ID to update"""
    @property
    def entity_spec(self) -> qwak.feature_store.entities.entity_pb2.EntitySpec:
        """Entity specifications to update"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
        entity_spec: qwak.feature_store.entities.entity_pb2.EntitySpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_spec", b"entity_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id", "entity_spec", b"entity_spec"]) -> None: ...

global___UpdateEntityRequest = UpdateEntityRequest

class UpdateEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """The updated entity"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___UpdateEntityResponse = UpdateEntityResponse

class CreateEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """The newly created entity"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___CreateEntityResponse = CreateEntityResponse

class GetEntityByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Id of the requested entity to fetch"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> None: ...

global___GetEntityByIdRequest = GetEntityByIdRequest

class GetEntityByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """Fetched entity by the requested id"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___GetEntityByIdResponse = GetEntityByIdResponse

class GetEntityByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_NAME_FIELD_NUMBER: builtins.int
    entity_name: builtins.str
    """Name of the requested entity to fetch"""
    def __init__(
        self,
        *,
        entity_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_name", b"entity_name"]) -> None: ...

global___GetEntityByNameRequest = GetEntityByNameRequest

class GetEntityByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.Entity:
        """Fetched entity by the requested name"""
    def __init__(
        self,
        *,
        entity: qwak.feature_store.entities.entity_pb2.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> None: ...

global___GetEntityByNameResponse = GetEntityByNameResponse

class DeleteEntityRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    entity_id: builtins.str
    """Id of the entity to be deleted"""
    def __init__(
        self,
        *,
        entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_id", b"entity_id"]) -> None: ...

global___DeleteEntityRequest = DeleteEntityRequest

class DeleteEntityResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteEntityResponse = DeleteEntityResponse

class ListEntitiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListEntitiesRequest = ListEntitiesRequest

class ListEntitiesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.entities.entity_pb2.Entity]:
        """All the entities belonging to the callers' partner id / user id"""
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[qwak.feature_store.entities.entity_pb2.Entity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities"]) -> None: ...

global___ListEntitiesResponse = ListEntitiesResponse
