"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Channel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NAME_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """Channel id"""
    channel_name: builtins.str
    """Channel name"""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        channel_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_id", b"channel_id", "channel_name", b"channel_name"]) -> None: ...

global___Channel = Channel

class FeatureSetAlertType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_FIELD_NUMBER: builtins.int
    @property
    def failure(self) -> global___FeatureSetFailureAlert: ...
    def __init__(
        self,
        *,
        failure: global___FeatureSetFailureAlert | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure", b"failure", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure", b"failure", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["failure"] | None: ...

global___FeatureSetAlertType = FeatureSetAlertType

class FeatureSetFailureAlert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Channel]:
        """Channels to alert"""
    def __init__(
        self,
        *,
        channels: collections.abc.Iterable[global___Channel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels", b"channels"]) -> None: ...

global___FeatureSetFailureAlert = FeatureSetFailureAlert

class FeatureSetAlertOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    ALERT_TYPES_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account id"""
    account_name: builtins.str
    """Account Name"""
    feature_set_name: builtins.str
    """FeatureSet Name"""
    feature_set_id: builtins.str
    """FeatureSet Id"""
    @property
    def alert_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureSetAlertType]:
        """Alert type"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        account_name: builtins.str = ...,
        feature_set_name: builtins.str = ...,
        feature_set_id: builtins.str = ...,
        alert_types: collections.abc.Iterable[global___FeatureSetAlertType] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "account_name", b"account_name", "alert_types", b"alert_types", "feature_set_id", b"feature_set_id", "feature_set_name", b"feature_set_name"]) -> None: ...

global___FeatureSetAlertOptions = FeatureSetAlertOptions
